@@ -1,9 +1,12 @@
-# Gitless - a version control system built on top of Git.
-# Licensed under GNU GPL v2.
+# -*- coding: utf-8 -*-
+# Gitless - a version control system built on top of Git
+# Licensed under MIT
 
 """gl resolve - Mark a file with conflicts as resolved."""
 
 
+from __future__ import unicode_literals
+
 from . import file_cmd
 
 
